@@ -11,7 +11,9 @@ from explainaboard.processors import (
     language_modeling,
     machine_translation,
     named_entity_recognition,
+    nlg_meta_evaluation,
     qa_multiple_choice,
+    qa_open_domain,
     summarization,
     tabular_classification,
     tabular_regression,
@@ -41,4 +43,6 @@ __all__ = [
     'cloze_multiple_choice',
     'cloze_generative',
     'grammatical_error_correction',
+    'qa_open_domain',
+    'nlg_meta_evaluation',
 ]
