@@ -3,7 +3,7 @@ import unittest
 
 from explainaboard import FileType, get_processor, TaskType
 from explainaboard.loaders.file_loader import FileLoaderMetadata
-from explainaboard.loaders.loader_registry import get_custom_dataset_loader
+from explainaboard.loaders.loader_registry import get_loader_class
 from explainaboard.metrics.ranking import (
     HitsConfig,
     MeanRankConfig,
@@ -24,7 +24,7 @@ class TestKgLinkTailPrediction(unittest.TestCase):
         # Load the data
         dataset = self.dataset_no_custom_feature
         task = TaskType.kg_link_tail_prediction
-        loader = get_custom_dataset_loader(task, dataset, dataset)
+        loader = get_loader_class(task)(dataset, dataset)
         data = loader.load()
         # Initialize the processor and perform the processing
         processor = get_processor(TaskType.kg_link_tail_prediction.value)
@@ -33,8 +33,7 @@ class TestKgLinkTailPrediction(unittest.TestCase):
         sys_info.write_to_directory('./')
 
     def test_no_user_defined_features(self):
-        loader = get_custom_dataset_loader(
-            TaskType.kg_link_tail_prediction,
+        loader = get_loader_class(TaskType.kg_link_tail_prediction)(
             self.test_data,
             self.dataset_no_custom_feature,
             dataset_file_type=FileType.json,
@@ -61,8 +60,8 @@ class TestKgLinkTailPrediction(unittest.TestCase):
         self.assertGreater(len(sys_info.results.overall), 0)
 
     def test_with_user_defined_features(self):
-        loader = get_custom_dataset_loader(  # use defaults
-            TaskType.kg_link_tail_prediction,
+        loader = get_loader_class(TaskType.kg_link_tail_prediction)(
+            # use defaults
             self.test_data,
             self.dataset_with_custom_feature,
         )
@@ -86,8 +85,7 @@ class TestKgLinkTailPrediction(unittest.TestCase):
         )
 
     def test_sort_buckets_by_value(self):
-        loader = get_custom_dataset_loader(
-            TaskType.kg_link_tail_prediction,
+        loader = get_loader_class(TaskType.kg_link_tail_prediction)(
             self.test_data,
             self.dataset_no_custom_feature,
         )
@@ -121,8 +119,7 @@ class TestKgLinkTailPrediction(unittest.TestCase):
             self.assertGreater(first_item, second_item)
 
     def test_sort_buckets_by_key(self):
-        loader = get_custom_dataset_loader(
-            TaskType.kg_link_tail_prediction,
+        loader = get_loader_class(TaskType.kg_link_tail_prediction)(
             self.test_data,
             self.dataset_no_custom_feature,
         )
