@@ -8,5 +8,5 @@ from explainaboard.utils.typing_utils import narrow
 class TestTypingUtils(unittest.TestCase):
     def test_narrow(self):
         a: str | int = 's'
-        self.assertEqual(narrow(a, str), a)
-        self.assertRaises(TypeError, lambda: narrow(a, int))
+        self.assertEqual(narrow(str, a), a)
+        self.assertRaises(TypeError, lambda: narrow(int, a))
